@@ -1,7 +1,8 @@
 from xtiff.ome import get_ome_xml
-from xtiff.tiff import to_tiff
+from xtiff.tiff import TiffProfile, to_tiff
 
 __all__ = [
     'get_ome_xml',
+    'TiffProfile',
     'to_tiff',
 ]
